Re-exports
pub use manifest::Manifest;Modules
Structs
The Error type, a wrapper around a dynamic error type.
Plugin contains everything needed to execute a WASM function
Handles memory for plugins
Statics
A registry for plugins
pub use manifest::Manifest;The Error type, a wrapper around a dynamic error type.
Plugin contains everything needed to execute a WASM function
Handles memory for plugins
A registry for plugins