Struct extism::PluginMemory
source · [−]pub struct PluginMemory {
pub store: Store<Internal>,
pub memory: Memory,
pub live_blocks: BTreeMap<usize, usize>,
pub free: Vec<MemoryBlock>,
pub position: usize,
}Expand description
Handles memory for plugins
Fields
store: Store<Internal>memory: Memorylive_blocks: BTreeMap<usize, usize>free: Vec<MemoryBlock>position: usizeImplementations
sourceimpl PluginMemory
impl PluginMemory
pub fn new(store: Store<Internal>, memory: Memory) -> Self
sourcepub fn write(
&mut self,
pos: impl Into<MemoryBlock>,
data: impl AsRef<[u8]>
) -> Result<(), MemoryAccessError>
pub fn write(
&mut self,
pos: impl Into<MemoryBlock>,
data: impl AsRef<[u8]>
) -> Result<(), MemoryAccessError>
Write to memory
sourcepub fn read(
&self,
pos: impl Into<MemoryBlock>,
data: impl AsMut<[u8]>
) -> Result<(), MemoryAccessError>
pub fn read(
&self,
pos: impl Into<MemoryBlock>,
data: impl AsMut<[u8]>
) -> Result<(), MemoryAccessError>
Read from memory
sourcepub fn alloc_bytes(
&mut self,
data: impl AsRef<[u8]>
) -> Result<MemoryBlock, Error>
pub fn alloc_bytes(
&mut self,
data: impl AsRef<[u8]>
) -> Result<MemoryBlock, Error>
Allocate and copy data into the wasm memory
sourcepub fn data(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn data(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Get memory as a slice of bytes
sourcepub fn data_mut(&mut self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn data_mut(&mut self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Get memory as a mutable slice of bytes
sourcepub fn get(&self, handle: impl Into<MemoryBlock>) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn get(&self, handle: impl Into<MemoryBlock>) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Get bytes occupied by the provided memory handle
sourcepub fn get_mut(&mut self, handle: impl Into<MemoryBlock>) -> &mut [u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn get_mut(&mut self, handle: impl Into<MemoryBlock>) -> &mut [u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Get mutable bytes occupied by the provided memory handle
sourcepub fn block_length(&self, offs: usize) -> Option<usize>
pub fn block_length(&self, offs: usize) -> Option<usize>
Get the length of the block starting at offs