pub struct Pool { /* private fields */ }Expand description
Pool manages threadsafe access to a limited number of instances of multiple plugins
Implementations
Sourceimpl Pool
impl Pool
Sourcepub fn new<F: 'static + Fn() -> Result<Plugin, Error> + Send + Sync>(
source: F,
) -> Self
pub fn new<F: 'static + Fn() -> Result<Plugin, Error> + Send + Sync>( source: F, ) -> Self
Create a new pool with the default configuration
Sourcepub fn new_from_builder<F: 'static + Fn() -> Result<Plugin, Error> + Send + Sync>(
source: F,
builder: PoolBuilder,
) -> Self
pub fn new_from_builder<F: 'static + Fn() -> Result<Plugin, Error> + Send + Sync>( source: F, builder: PoolBuilder, ) -> Self
Create a new pool configured using a PoolBuilder
Sourcepub fn count(&self) -> usize
pub fn count(&self) -> usize
Get the number of live instances for a plugin (both checked out and available)
Sourcepub fn get(&self, timeout: Duration) -> Result<Option<PoolPlugin>, Error>
pub fn get(&self, timeout: Duration) -> Result<Option<PoolPlugin>, Error>
Get access to a plugin, this will create a new instance if needed (and allowed by the specified
max_instances). Ok(None) is returned if the timeout is reached before an available plugin could be
acquired
Sourcepub fn with_plugin<T>(
&self,
timeout: Duration,
f: impl FnOnce(&mut Plugin) -> Result<T, Error>,
) -> Result<Option<T>, Error>
pub fn with_plugin<T>( &self, timeout: Duration, f: impl FnOnce(&mut Plugin) -> Result<T, Error>, ) -> Result<Option<T>, Error>
Access a plugin in a callback function. This calls Pool::get then the provided callback. Ok(None)
is returned if the timeout is reached before an available plugin could be acquired